@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,11 +14,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_EXEC_BUFFER_H
-#define WEECHAT_EXEC_BUFFER_H 1
+#ifndef WEECHAT_PLUGIN_EXEC_BUFFER_H
+#define WEECHAT_PLUGIN_EXEC_BUFFER_H
 
 extern void exec_buffer_set_callbacks ();
 extern struct t_gui_buffer *exec_buffer_new (const char *name,
@@ -26,4 +26,4 @@ extern struct t_gui_buffer *exec_buffer_new (const char *name,
                                              int clear_buffer,
                                              int switch_to_buffer);
 
-#endif /* WEECHAT_EXEC_BUFFER_H */
+#endif /* WEECHAT_PLUGIN_EXEC_BUFFER_H */
