@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013 Koka El Kiwi <kokakiwi@kokakiwi.net>
- * Copyright (C) 2015-2016 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2015-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -15,16 +15,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_JS_API_H
-#define WEECHAT_JS_API_H 1
+#ifndef WEECHAT_PLUGIN_JS_API_H
+#define WEECHAT_PLUGIN_JS_API_H
 
-extern int weechat_js_api_buffer_input_data_cb (void *data,
+extern int weechat_js_api_buffer_input_data_cb (const void *pointer,
+                                                void *data,
                                                 struct t_gui_buffer *buffer,
                                                 const char *input_data);
-extern int weechat_js_api_buffer_close_cb (void *data,
+extern int weechat_js_api_buffer_close_cb (const void *pointer,
+                                           void *data,
                                            struct t_gui_buffer *buffer);
 
-#endif /* WEECHAT_JS_API_H */
+#endif /* WEECHAT_PLUGIN_JS_API_H */
