@@ -1,7 +1,7 @@
 /*
  * script-config.c - script configuration options (file script.conf)
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -34,9 +34,6 @@
 
 
 struct t_config_file *script_config_file = NULL;
-struct t_config_section *script_config_section_look = NULL;
-struct t_config_section *script_config_section_color = NULL;
-struct t_config_section *script_config_section_scripts = NULL;
 
 /* script config, look section */
 
@@ -82,10 +79,11 @@ struct t_config_option *script_config_color_text_version_selected;
 
 struct t_config_option *script_config_scripts_autoload;
 struct t_config_option *script_config_scripts_cache_expire;
-struct t_config_option *script_config_scripts_path;
+struct t_config_option *script_config_scripts_download_enabled;
+struct t_config_option *script_config_scripts_download_timeout;
 struct t_config_option *script_config_scripts_hold;
+struct t_config_option *script_config_scripts_path;
 struct t_config_option *script_config_scripts_url;
-struct t_config_option *script_config_scripts_url_force_https;
 
 
 /*
@@ -99,7 +97,8 @@ struct t_config_option *script_config_scripts_url_force_https;
 const char *
 script_config_get_diff_command ()
 {
-    const char *diff_command, *dir_separator;
+    const char *diff_command;
+    char *dir_separator;
     static char result[64];
     struct stat st;
     char *path, **paths, bin[4096];
@@ -116,7 +115,11 @@ script_config_get_diff_command ()
         result[0] = '\0';
         if (dir_separator && path)
         {
-            paths = weechat_string_split (path, ":", 0, 0, &num_paths);
+            paths = weechat_string_split (path, ":", NULL,
+                                          WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                          | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                          | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                          0, &num_paths);
             if (paths)
             {
                 for (i = 0; i < num_paths; i++)
@@ -134,6 +137,8 @@ script_config_get_diff_command ()
                 weechat_string_free_split (paths);
             }
         }
+        if (dir_separator)
+            free (dir_separator);
         if (!result[0])
             snprintf (result, sizeof (result), "diff");
         return result;
@@ -143,8 +148,7 @@ script_config_get_diff_command ()
 }
 
 /*
- * Gets filename with script
- * (by default "/home/xxx/.weechat/script/plugins.xml.gz").
+ * Gets filename with list of scripts.
  *
  * Note: result must be freed after use.
  */
@@ -154,9 +158,19 @@ script_config_get_xml_filename ()
 {
     char *path, *filename;
     int length;
+    struct t_hashtable *options;
 
+    options = weechat_hashtable_new (
+        32,
+        WEECHAT_HASHTABLE_STRING,
+        WEECHAT_HASHTABLE_STRING,
+        NULL, NULL);
+    if (options)
+        weechat_hashtable_set (options, "directory", "cache");
     path = weechat_string_eval_path_home (
-        weechat_config_string (script_config_scripts_path), NULL, NULL, NULL);
+        weechat_config_string (script_config_scripts_path), NULL, NULL, options);
+    if (options)
+        weechat_hashtable_free (options);
     length = strlen (path) + 64;
     filename = malloc (length);
     if (filename)
@@ -167,11 +181,8 @@ script_config_get_xml_filename ()
 
 /*
  * Gets filename for a script to download.
- *
  * If suffix is not NULL, it is added to filename.
  *
- * Example: "/home/xxx/.weechat/script/iset.pl"
- *
  * Note: result must be freed after use.
  */
 
@@ -181,9 +192,19 @@ script_config_get_script_download_filename (struct t_script_repo *script,
 {
     char *path, *filename;
     int length;
+    struct t_hashtable *options;
 
+    options = weechat_hashtable_new (
+        32,
+        WEECHAT_HASHTABLE_STRING,
+        WEECHAT_HASHTABLE_STRING,
+        NULL, NULL);
+    if (options)
+        weechat_hashtable_set (options, "directory", "cache");
     path = weechat_string_eval_path_home (
-        weechat_config_string (script_config_scripts_path), NULL, NULL, NULL);
+        weechat_config_string (script_config_scripts_path), NULL, NULL, options);
+    if (options)
+        weechat_hashtable_free (options);
     length = strlen (path) + 1 + strlen (script->name_with_extension)
         + ((suffix) ? strlen (suffix) : 0) + 1;
     filename = malloc (length);
@@ -204,9 +225,11 @@ script_config_get_script_download_filename (struct t_script_repo *script,
  */
 
 void
-script_config_refresh_cb (void *data, struct t_config_option *option)
+script_config_refresh_cb (const void *pointer, void *data,
+                          struct t_config_option *option)
 {
     /* make C compiler happy */
+    (void) pointer;
     (void) data;
     (void) option;
 
@@ -220,9 +243,11 @@ script_config_refresh_cb (void *data, struct t_config_option *option)
  */
 
 void
-script_config_reload_scripts_cb (void *data, struct t_config_option *option)
+script_config_reload_scripts_cb (const void *pointer, void *data,
+                                 struct t_config_option *option)
 {
     /* make C compiler happy */
+    (void) pointer;
     (void) data;
     (void) option;
 
@@ -239,9 +264,11 @@ script_config_reload_scripts_cb (void *data, struct t_config_option *option)
  */
 
 void
-script_config_change_use_keys_cb (void *data, struct t_config_option *option)
+script_config_change_use_keys_cb (const void *pointer, void *data,
+                                  struct t_config_option *option)
 {
     /* make C compiler happy */
+    (void) pointer;
     (void) data;
     (void) option;
 
@@ -254,9 +281,11 @@ script_config_change_use_keys_cb (void *data, struct t_config_option *option)
  */
 
 void
-script_config_change_hold_cb (void *data, struct t_config_option *option)
+script_config_change_hold_cb (const void *pointer, void *data,
+                              struct t_config_option *option)
 {
     /* make C compiler happy */
+    (void) pointer;
     (void) data;
     (void) option;
 
@@ -284,8 +313,15 @@ script_config_hold (const char *name_with_extension)
     if (hold)
     {
         hold[0] = '\0';
-        items = weechat_string_split (weechat_config_string (script_config_scripts_hold),
-                                      ",", 0, 0, &num_items);
+        items = weechat_string_split (
+            weechat_config_string (script_config_scripts_hold),
+            ",",
+            NULL,
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+            0,
+            &num_items);
         if (items)
         {
             for (i = 0; i < num_items; i++)
@@ -327,8 +363,15 @@ script_config_unhold (const char *name_with_extension)
     if (hold)
     {
         hold[0] = '\0';
-        items = weechat_string_split (weechat_config_string (script_config_scripts_hold),
-                                      ",", 0, 0, &num_items);
+        items = weechat_string_split (
+            weechat_config_string (script_config_scripts_hold),
+            ",",
+            NULL,
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+            0,
+            &num_items);
         if (items)
         {
             for (i = 0; i < num_items; i++)
@@ -354,9 +397,11 @@ script_config_unhold (const char *name_with_extension)
  */
 
 int
-script_config_reload (void *data, struct t_config_file *config_file)
+script_config_reload (const void *pointer, void *data,
+                      struct t_config_file *config_file)
 {
     /* make C compiler happy */
+    (void) pointer;
     (void) data;
 
     return weechat_config_reload (config_file);
@@ -376,19 +421,22 @@ script_config_init ()
     struct t_config_section *ptr_section;
 
     script_config_file = weechat_config_new (SCRIPT_CONFIG_NAME,
-                                             &script_config_reload, NULL);
+                                             &script_config_reload, NULL, NULL);
     if (!script_config_file)
         return 0;
 
     /* look */
     ptr_section = weechat_config_new_section (script_config_file, "look",
                                               0, 0,
-                                              NULL, NULL, NULL, NULL,
-                                              NULL, NULL, NULL, NULL,
-                                              NULL, NULL);
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL);
     if (!ptr_section)
     {
         weechat_config_free (script_config_file);
+        script_config_file = NULL;
         return 0;
     }
 
@@ -396,19 +444,21 @@ script_config_init ()
         script_config_file, ptr_section,
         "columns", "string",
         N_("format of columns displayed in script buffer: following column "
-           "identifiers are replaced by their value: %a=author, %d=description, "
+           "identifiers are replaced by their values: %a=author, %d=description, "
            "%D=date added, %e=extension, %l=language, %L=license, %n=name with "
            "extension, %N=name, %r=requirements, %s=status, %t=tags, "
            "%u=date updated, %v=version, %V=version loaded, %w=min_weechat, "
            "%W=max_weechat)"),
         NULL, 0, 0, "%s %n %V %v %u | %d | %t", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_look_diff_color = weechat_config_new_option (
         script_config_file, ptr_section,
         "diff_color", "boolean",
         N_("colorize output of diff"),
         NULL, 0, 0, "on", NULL, 0,
-        NULL, NULL, NULL, NULL, NULL, NULL);
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     script_config_look_diff_command = weechat_config_new_option (
         script_config_file, ptr_section,
         "diff_command", "string",
@@ -417,7 +467,7 @@ script_config_init ()
            "or diff), empty value = disable diff, other string = name of "
            "command, for example \"diff\")"),
         NULL, 0, 0, "auto", NULL, 0,
-        NULL, NULL, NULL, NULL, NULL, NULL);
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     script_config_look_display_source = weechat_config_new_option (
         script_config_file, ptr_section,
         "display_source", "boolean",
@@ -425,7 +475,7 @@ script_config_init ()
            "(script is downloaded in a temporary file when detail on script "
            "is displayed)"),
         NULL, 0, 0, "on", NULL, 0,
-        NULL, NULL, NULL, NULL, NULL, NULL);
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     script_config_look_quiet_actions = weechat_config_new_option (
         script_config_file, ptr_section,
         "quiet_actions", "boolean",
@@ -433,7 +483,7 @@ script_config_init ()
            "buffer when scripts are installed/removed/loaded/unloaded (only "
            "errors are displayed)"),
         NULL, 0, 0, "on", NULL, 0,
-        NULL, NULL, NULL, NULL, NULL, NULL);
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     script_config_look_sort = weechat_config_new_option (
         script_config_file, ptr_section,
         "sort", "string",
@@ -443,15 +493,19 @@ script_config_init ()
            "u=date updated; char \"-\" can be used before identifier to reverse "
            "order; example: \"i,u\": installed scripts first, sorted by update "
            "date"),
-        NULL, 0, 0, "p,n", NULL, 0,
-        NULL, NULL, &script_config_reload_scripts_cb, NULL, NULL, NULL);
+        NULL, 0, 0, "i,p,n", NULL, 0,
+        NULL, NULL, NULL,
+        &script_config_reload_scripts_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_look_translate_description = weechat_config_new_option (
         script_config_file, ptr_section,
         "translate_description", "boolean",
         N_("translate description of scripts (if translation is available in "
            "your language, otherwise English version is used)"),
         NULL, 0, 0, "on", NULL, 0,
-        NULL, NULL, &script_config_reload_scripts_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_reload_scripts_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_look_use_keys = weechat_config_new_option (
         script_config_file, ptr_section,
         "use_keys", "boolean",
@@ -459,17 +513,22 @@ script_config_init ()
            "install, alt+r = remove, ...); if disabled, only the input is "
            "allowed: i, r, ..."),
         NULL, 0, 0, "on", NULL, 0,
-        NULL, NULL, &script_config_change_use_keys_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_change_use_keys_cb, NULL, NULL,
+        NULL, NULL, NULL);
 
     /* color */
     ptr_section = weechat_config_new_section (script_config_file, "color",
                                               0, 0,
-                                              NULL, NULL, NULL, NULL,
-                                              NULL, NULL, NULL, NULL,
-                                              NULL, NULL);
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL);
     if (!ptr_section)
     {
         weechat_config_free (script_config_file);
+        script_config_file = NULL;
         return 0;
     }
 
@@ -478,167 +537,222 @@ script_config_init ()
         "status_autoloaded", "color",
         N_("color for status \"autoloaded\" (\"a\")"),
         NULL, 0, 0, "cyan", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_status_held = weechat_config_new_option (
         script_config_file, ptr_section,
         "status_held", "color",
         N_("color for status \"held\" (\"H\")"),
         NULL, 0, 0, "white", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_status_installed = weechat_config_new_option (
         script_config_file, ptr_section,
         "status_installed", "color",
         N_("color for status \"installed\" (\"i\")"),
         NULL, 0, 0, "lightcyan", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_status_obsolete = weechat_config_new_option (
         script_config_file, ptr_section,
         "status_obsolete", "color",
         N_("color for status \"obsolete\" (\"N\")"),
         NULL, 0, 0, "lightmagenta", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_status_popular = weechat_config_new_option (
         script_config_file, ptr_section,
         "status_popular", "color",
         N_("color for status \"popular\" (\"*\")"),
         NULL, 0, 0, "yellow", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_status_running = weechat_config_new_option (
         script_config_file, ptr_section,
         "status_running", "color",
         N_("color for status \"running\" (\"r\")"),
         NULL, 0, 0, "lightgreen", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_status_unknown = weechat_config_new_option (
         script_config_file, ptr_section,
         "status_unknown", "color",
         N_("color for status \"unknown\" (\"?\")"),
         NULL, 0, 0, "lightred", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text = weechat_config_new_option (
         script_config_file, ptr_section,
         "text", "color",
         N_("text color in script buffer"),
         NULL, 0, 0, "default", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_bg = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_bg", "color",
         N_("background color in script buffer"),
         NULL, 0, 0, "default", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_bg_selected = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_bg_selected", "color",
         N_("background color for selected line in script buffer"),
         NULL, 0, 0, "red", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_date = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_date", "color",
         N_("text color of dates in script buffer"),
         NULL, 0, 0, "default", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_date_selected = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_date_selected", "color",
         N_("text color of dates for selected line in script buffer"),
         NULL, 0, 0, "white", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_delimiters = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_delimiters", "color",
         N_("text color of delimiters in script buffer"),
         NULL, 0, 0, "default", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_description = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_description", "color",
         N_("text color of description in script buffer"),
         NULL, 0, 0, "default", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_description_selected = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_description_selected", "color",
         N_("text color of description for selected line in script buffer"),
         NULL, 0, 0, "white", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_extension = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_extension", "color",
         N_("text color of extension in script buffer"),
         NULL, 0, 0, "default", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_extension_selected = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_extension_selected", "color",
         N_("text color of extension for selected line in script buffer"),
         NULL, 0, 0, "white", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_name = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_name", "color",
         N_("text color of script name in script buffer"),
         NULL, 0, 0, "cyan", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_name_selected = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_name_selected", "color",
         N_("text color of script name for selected line in script buffer"),
         NULL, 0, 0, "lightcyan", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_selected = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_selected", "color",
         N_("text color for selected line in script buffer"),
         NULL, 0, 0, "white", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_tags = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_tags", "color",
         N_("text color of tags in script buffer"),
         NULL, 0, 0, "brown", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_tags_selected = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_tags_selected", "color",
         N_("text color of tags for selected line in script buffer"),
         NULL, 0, 0, "yellow", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_version = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_version", "color",
         N_("text color of version in script buffer"),
         NULL, 0, 0, "magenta", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_version_loaded = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_version_loaded", "color",
         N_("text color of version loaded in script buffer"),
         NULL, 0, 0, "default", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_version_loaded_selected = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_version_loaded_selected", "color",
         N_("text color of version loaded for selected line in script buffer"),
         NULL, 0, 0, "white", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     script_config_color_text_version_selected = weechat_config_new_option (
         script_config_file, ptr_section,
         "text_version_selected", "color",
         N_("text color of version for selected line in script buffer"),
         NULL, 0, 0, "lightmagenta", NULL, 0,
-        NULL, NULL, &script_config_refresh_cb, NULL, NULL, NULL);
+        NULL, NULL, NULL,
+        &script_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
 
     /* scripts */
     ptr_section = weechat_config_new_section (script_config_file, "scripts",
                                               0, 0,
-                                              NULL, NULL, NULL, NULL,
-                                              NULL, NULL, NULL, NULL,
-                                              NULL, NULL);
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL);
     if (!ptr_section)
     {
         weechat_config_free (script_config_file);
+        script_config_file = NULL;
         return 0;
     }
 
@@ -648,45 +762,55 @@ script_config_init ()
         N_("autoload scripts installed (make a link in \"autoload\" directory "
            "to script in parent directory)"),
         NULL, 0, 0, "on", NULL, 0,
-        NULL, NULL, NULL, NULL, NULL, NULL);
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     script_config_scripts_cache_expire = weechat_config_new_option (
         script_config_file, ptr_section,
         "cache_expire", "integer",
         N_("local cache expiration time, in minutes (-1 = never expires, "
            "0 = always expire)"),
-        NULL, -1, 525600, "1440", NULL, 0, NULL, NULL,
-        NULL, NULL, NULL, NULL);
-    script_config_scripts_path = weechat_config_new_option (
+        NULL, -1, 525600, "1440", NULL, 0,
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+    script_config_scripts_download_enabled = weechat_config_new_option (
         script_config_file, ptr_section,
-        "path", "string",
-        N_("local cache directory for scripts; \"%h\" at beginning of string "
-           "is replaced by WeeChat home (\"~/.weechat\" by default) "
-           "(note: content is evaluated, see /help eval)"),
-        NULL, 0, 0, "%h/script", NULL, 0, NULL, NULL,
-        NULL, NULL, NULL, NULL);
+        "download_enabled", "boolean",
+        N_("enable download of files from the scripts repository when the "
+           "/script command is used (list of scripts and scripts themselves); "
+           "the list of scripts is downloaded from the URL specified in the "
+           "option script.scripts.url; WeeChat will sometimes download again "
+           "the list of scripts when you use the /script command, even if "
+           "you don't install a script"),
+        NULL, 0, 0, "off", NULL, 0,
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+    script_config_scripts_download_timeout = weechat_config_new_option (
+        script_config_file, ptr_section,
+        "download_timeout", "integer",
+        N_("timeout (in seconds) for download of scripts and list of scripts"),
+        NULL, 1, 3600, "30", NULL, 0,
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     script_config_scripts_hold = weechat_config_new_option (
         script_config_file, ptr_section,
         "hold", "string",
         N_("scripts to \"hold\": comma-separated list of scripts which will "
            "never been upgraded and can not be removed, for example: "
-           "\"buffers.pl,iset.pl\""),
-        NULL, 0, 0, "", NULL, 0, NULL, NULL,
-        &script_config_change_hold_cb, NULL, NULL, NULL);
+           "\"go.py,urlserver.py\""),
+        NULL, 0, 0, "", NULL, 0,
+        NULL, NULL, NULL,
+        &script_config_change_hold_cb, NULL, NULL,
+        NULL, NULL, NULL);
+    script_config_scripts_path = weechat_config_new_option (
+        script_config_file, ptr_section,
+        "path", "string",
+        N_("local cache directory for scripts "
+           "(path is evaluated, see function string_eval_path_home in "
+           "plugin API reference)"),
+        NULL, 0, 0, "${weechat_cache_dir}/script", NULL, 0,
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     script_config_scripts_url = weechat_config_new_option (
         script_config_file, ptr_section,
         "url", "string",
-        N_("URL for file with list of scripts; by default HTTPS is forced, "
-           "see option script.scripts.url_force_https"),
-        NULL, 0, 0, "http://weechat.org/files/plugins.xml.gz", NULL, 0, NULL, NULL,
-        NULL, NULL, NULL, NULL);
-    script_config_scripts_url_force_https = weechat_config_new_option (
-        script_config_file, ptr_section,
-        "url_force_https", "boolean",
-        N_("force use of HTTPS for downloads (index and scripts); "
-           "you should disable this option only if you have problems with "
-           "the downloads"),
-        NULL, 0, 0, "on", NULL, 0, NULL, NULL,
-        NULL, NULL, NULL, NULL);
+        N_("URL for file with list of scripts"),
+        NULL, 0, 0, "https://weechat.org/files/plugins.xml.gz", NULL, 0,
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 
     return 1;
 }
