@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,12 +14,19 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_XFER_NETWORK_H
-#define WEECHAT_XFER_NETWORK_H 1
+#ifndef WEECHAT_PLUGIN_XFER_NETWORK_H
+#define WEECHAT_PLUGIN_XFER_NETWORK_H
 
+#include <sys/socket.h>
+
+extern int xfer_network_resolve_addr (const char *str_address,
+                                      const char *str_port,
+                                      struct sockaddr *addr,
+                                      socklen_t *addr_len,
+                                      int ai_flags);
 extern void xfer_network_write_pipe (struct t_xfer *xfer, int status,
                                      int error);
 extern void xfer_network_connect_init (struct t_xfer *xfer);
@@ -27,4 +34,4 @@ extern void xfer_network_child_kill (struct t_xfer *xfer);
 extern int xfer_network_connect (struct t_xfer *xfer);
 extern void xfer_network_accept (struct t_xfer *xfer);
 
-#endif /* WEECHAT_XFER_NETWORK_H */
+#endif /* WEECHAT_PLUGIN_XFER_NETWORK_H */
